import Vue from 'vue'
import axios from 'axios'
import store from '@/store'
import {Plugin as VueAxios} from '@/plugins/axios'
import {Modal, MessageBox ,Notification} from 'element-ui'
import {ACCESS_TOKEN} from "@/store/mutation-types"
import router from 'vue-router'
// 创建 axios 实例

if (process.env.NODE_ENV == 'development') { 
    axios.defaults.baseURL = '/api'
} 
else if (process.env.NODE_ENV == 'debug') { 
} 
else if (process.env.NODE_ENV == 'production') { 
    // axios.defaults.baseURL = 'http://192.168.1.251/jeecg-boot';
  axios.defaults.baseURL = 'http://okrapi.c-top.com.cn';
}
const service = axios.create({
  // baseURL: '/jeecg-boot', // api base_url
  timeout: 6000000 // 请求超时时间
})




const err = (error) => {
  if (error.response) {
    let data = error.response.data
    const token = Vue.ls.get(ACCESS_TOKEN)
    console.log("------异常响应------", token,data)
    // console.log("------异常响应------", error.response.status)
    switch (error.response.status) {
      case 403:
        Notification.error({title: '系统提示', message: '拒绝访问', duration: 4})
        break
      case 500:
        //notification.error({ message: '系统提示', description:'Token失效，请重新登录!',duration: 4})
        if (data.code == -1) {
          // update-begin- --- author:scott ------ date:20190225 ---- for:Token失效采用弹框模式，不直接跳转----
          // store.dispatch('Logout').then(() => {
          //     window.location.reload()
          // })
          // Notification.error({title: '登录已过期', message: '很抱歉，登录已过期，请重新登录', duration: 4})
          
            store.dispatch('Logout').then(() => {
              setTimeout(() => {
                window.location.reload()
                // router.replace('/login')
              }, 50)
            })
          
          break
         
          // update-end- --- author:scott ------ date:20190225 ---- for:Token失效采用弹框模式，不直接跳转----
        }
        break
      case 404:
        Notification.error({title: '系统提示', message: '很抱歉，资源未找到!', duration: 4})
        break
      case 504:
        Notification.error({title: '系统提示', message: '网络超时'})
        break
      case 401:
        Notification.error({title: '系统提示', message: '未授权，请重新登录', duration: 4})
        
          store.dispatch('Logout').then(() => {
            setTimeout(() => {
              window.location.reload()
            }, 50)
          })
        
        break
      default:
        Notification.error({
          title: '系统提示',
          message: data.message,
          duration: 4
        })
        break
    }
  }
  return Promise.reject(error)
};

// request interceptor
service.interceptors.request.use(config => {
  const token = Vue.ls.get(ACCESS_TOKEN);
  // let tokens=JSON.parse(localStorage.getItem('ACCESS_TOKEN'))
  console.log(token)
  if (token) {
      config.headers['X-Access-Token'] = token// 让每个请求携带自定义 token 请根据实际情况自行修改
  }
  if (config.method == 'get') {
    config.params = {
      _t: Date.parse(new Date()) / 1000,

      ...config.params
    }
  }
  return config
}, (error) => {
  return Promise.reject(error)
})

// response interceptor
service.interceptors.response.use((response) => {
  return response.data
}, (error) => {
  console.log(error)
    err(error)
      // Notification.error({
      //   title: '系统提示',
      //   message: '网络超时,请刷新页面'
      // })
    return 
  })

const installer = {
  vm: {},
  install(Vue, router = {}) {
    Vue.use(VueAxios, router, service)
  }
}

export {
  installer as VueAxios,
  service as axios
}